# Copyright 2023 The Fury Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import os
import sys
import warnings

try:
    import pyarrow as pa

    # Ensure fury can link to arrow shared library
    sys.path.extend(pa.get_library_dirs() + [os.path.dirname(__file__)])

    from pyfury.format._format import (  # noqa: F401 # pylint: disable=unused-import
        create_row_encoder,
        RowData,
        ArrowWriter,
    )  # noqa: E402
    from pyfury.format.infer import (  # noqa: F401 # pylint: disable=unused-import
        get_cls_by_schema,
        remove_schema,
        reset,
    )
    from pyfury.format.encoder import (  # noqa: F401 # pylint: disable=unused-import
        encoder,
        Encoder,
    )
except (ImportError, AttributeError) as e:
    warnings.warn(
        f"Fury format initialization failed, please ensure pyarrow is installed "
        f"with version which fury is compiled with: {e}",
        RuntimeWarning,
        stacklevel=2,
    )
